@@ -5,13 +5,13 @@ from sdv.tabular.ctgan import CTGAN
 def test_ctgan():
     users = load_demo(metadata=False)['users']
 
-    gc = CTGAN(
+    ctgan = CTGAN(
         primary_key='user_id',
         epochs=1
     )
-    gc.fit(users)
+    ctgan.fit(users)
 
-    sampled = gc.sample()
+    sampled = ctgan.sample()
 
     # test shape is right
     assert sampled.shape == users.shape
@@ -19,11 +19,13 @@ def test_ctgan():
     # test user_id has been generated as an ID field
     assert list(sampled['user_id']) == list(range(0, len(users)))
 
-    assert gc.get_metadata().to_dict() == {
+    assert ctgan.get_metadata().to_dict() == {
         'fields': {
             'user_id': {'type': 'id', 'subtype': 'integer'},
             'country': {'type': 'categorical'},
             'gender': {'type': 'categorical'},
             'age': {'type': 'numerical', 'subtype': 'integer'}
-        }
+        },
+        'constraints': [],
+        'model_kwargs': {}
     }
